# This file has been generated


build_system = 'AppVeyor'
build_id = '31957355'
build_number = '641'
build_version = '1.0.641'
job_id = 'lr2o7b21bs9efxc8'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/lr2o7b21bs9efxc8'
